@@ -2,7 +2,7 @@ package Mojo::SAML;
 
 use Mojo::Base -strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 $VERSION = eval $VERSION;
 
 use constant ();
@@ -11,6 +11,7 @@ use Mojo::Util;
 
 our @doc_types = (qw/
   AssertionConsumerService
+  AttributeConsumingService
   AuthnRequest
   ContactPerson
   EntityDescriptor
@@ -18,6 +19,7 @@ our @doc_types = (qw/
   KeyInfo
   NameIDPolicy
   Organization
+  RequestedAttribute
   Signature
   SPSSODescriptor
 /);
@@ -85,6 +87,10 @@ Their name is both the name of the subclass and the tag that they create.
 
 Constant shortcut to L<Mojo::SAML::Document::AssertionConsumerService>.
 
+=head3 AttributeConsumingService
+
+Constant shortcut to L<Mojo::SAML::Document::AttributeConsumingService>.
+
 =head3 AuthnRequest
 
 Constant shortcut to L<Mojo::SAML::Document::AuthnRequest>.
@@ -113,6 +119,10 @@ Constant shortcut to L<Mojo::SAML::Document::NameIDPolicy>.
 
 Constant shortcut to L<Mojo::SAML::Document::Organization>.
 
+=head3 RequestedAttribute
+
+Constant shortcut to L<Mojo::SAML::Document::RequestedAttribute>.
+
 =head3 Signature
 
 Constant shortcut to L<Mojo::SAML::Document::Signature>.
@@ -131,7 +141,7 @@ Exports all of the above document type constants.
 
 While they aren't linked to from this module, some other modules that will likely be useful are:
 
-=head Mojo::SAML::Names
+=head2 Mojo::SAML::Names
 
 L<Mojo::SAML::Names> is a (fairly incomplete) list of naming conventions and standard used in SAML.
 
